"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = exports.AppApiTypes = void 0;

var _reduxsauce = require("reduxsauce");

/**
 * We use reduxsauce's `createActions()` helper to easily create redux actions.
 *
 * Keys are action names and values are the list of parameters for the given action.
 *
 * Action names are turned to SNAKE_CASE into the `Types` variable. This can be used
 * to listen to actions:
 *
 * - to trigger reducers to update the state, for example in App/Stores/Example/Reducers.js
 * - to trigger sagas, for example in App/Sagas/index.js
 *
 * Actions can be dispatched:
 *
 * - in React components using `dispatch(...)`, for example in @App/App.js
 * - in sagas using `yield put(...)`, for example in App/Sagas/ExampleSaga.js
 *
 * @see https://github.com/infinitered/reduxsauce#createactions
 */
var _createActions = (0, _reduxsauce.createActions)({
  // This action triggered when the app requires user to wait.
  onApiFetching: ['config'],
  onApiFetchSuccess: ['data'],
  onApiFetchFailure: ['error']
}),
    Types = _createActions.Types,
    Creators = _createActions.Creators;

var AppApiTypes = Types;
exports.AppApiTypes = AppApiTypes;
var _default = Creators;
exports["default"] = _default;